@@ -2,7 +2,7 @@
 #
 ## plugins/triggers/triggers.py
 ##
-## Copyright (C) 2011 Yann Leboulanger <asterix AT lagaule.org>
+## Copyright (C) 2011-2017 Yann Leboulanger <asterix AT lagaule.org>
 ##
 ## This file is part of Gajim.
 ##
@@ -19,21 +19,21 @@
 ## along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 ##
 
-import gtk
+from gi.repository import Gtk
 import sys
 import os
 
-from common import gajim
-from plugins import GajimPlugin
-from plugins.helpers import log_calls
-from plugins.gui import GajimPluginConfigDialog
-from common import ged
-from common import helpers
-from dialogs import SoundChooserDialog
+from gajim.common import app
+from gajim.common import ged
+from gajim.common import helpers
+from gajim.plugins import GajimPlugin
+from gajim.plugins.helpers import log_calls
+from gajim.plugins.gui import GajimPluginConfigDialog
+
+from gajim.dialogs import SoundChooserDialog
 
 
 class Triggers(GajimPlugin):
-
     @log_calls('TriggersPlugin')
     def init(self):
         self.description = _('Configure Gajim\'s behaviour for each contact')
@@ -55,7 +55,8 @@ class Triggers(GajimPlugin):
         if rule['recipient_type'] == 'contact' and obj.jid not in \
         rule_recipients:
             return False
-        contact = gajim.contacts.get_first_contact_from_jid(obj.conn.name, obj.jid)
+        contact = app.contacts.get_first_contact_from_jid(obj.conn.name,
+            obj.jid)
         if not contact:  # PM?
             return False
         contact_groups = contact.groups
@@ -71,7 +72,7 @@ class Triggers(GajimPlugin):
 
     def _check_rule_status(self, obj, rule):
         rule_statuses = rule['status'].split()
-        our_status = gajim.SHOW_LIST[obj.conn.connected]
+        our_status = app.SHOW_LIST[obj.conn.connected]
         if rule['status'] != 'all' and our_status not in rule_statuses:
             return False
 
@@ -81,7 +82,7 @@ class Triggers(GajimPlugin):
         if rule['tab_opened'] == 'both':
             return True
         tab_opened = False
-        if gajim.interface.msg_win_mgr.get_control(obj.jid, obj.conn.name):
+        if app.interface.msg_win_mgr.get_control(obj.jid, obj.conn.name):
             tab_opened = True
         if tab_opened and rule['tab_opened'] == 'no':
             return False
@@ -96,7 +97,7 @@ class Triggers(GajimPlugin):
         if rule['tab_opened'] == 'no':
             # Does not apply in this case
             return True
-        ctrl = gajim.interface.msg_win_mgr.get_control(obj.jid, obj.conn.name)
+        ctrl = app.interface.msg_win_mgr.get_control(obj.jid, obj.conn.name)
         if not ctrl:
             # Does not apply in this case
             return True
@@ -273,12 +274,12 @@ class TriggersPluginConfigDialog(GajimPluginConfigDialog):
     def init(self):
         self.GTK_BUILDER_FILE_PATH = self.plugin.local_file_path(
             'config_dialog.ui')
-        self.xml = gtk.Builder()
+        self.xml = Gtk.Builder()
         self.xml.set_translation_domain('gajim_plugins')
         self.xml.add_objects_from_file(self.GTK_BUILDER_FILE_PATH,
             ['vbox', 'liststore1', 'liststore2'])
         vbox = self.xml.get_object('vbox')
-        self.child.pack_start(vbox)
+        self.get_child().pack_start(vbox, True, True, 0)
 
         self.xml.connect_signals(self)
         self.connect('hide', self.on_hide)
@@ -313,22 +314,22 @@ class TriggersPluginConfigDialog(GajimPluginConfigDialog):
 
         if not self.conditions_treeview.get_column(0):
             # window never opened
-            model = gtk.ListStore(int, str)
-            model.set_sort_column_id(0, gtk.SORT_ASCENDING)
+            model = Gtk.ListStore(int, str)
+            model.set_sort_column_id(0, Gtk.SortType.ASCENDING)
             self.conditions_treeview.set_model(model)
 
             # means number
-            col = gtk.TreeViewColumn(_('#'))
+            col = Gtk.TreeViewColumn(_('#'))
             self.conditions_treeview.append_column(col)
-            renderer = gtk.CellRendererText()
+            renderer = Gtk.CellRendererText()
             col.pack_start(renderer, expand=False)
-            col.set_attributes(renderer, text=0)
+            col.add_attribute(renderer, 'text', 0)
 
-            col = gtk.TreeViewColumn(_('Condition'))
+            col = Gtk.TreeViewColumn(_('Condition'))
             self.conditions_treeview.append_column(col)
-            renderer = gtk.CellRendererText()
+            renderer = Gtk.CellRendererText()
             col.pack_start(renderer, expand=True)
-            col.set_attributes(renderer, text=1)
+            col.add_attribute(renderer, 'text', 1)
         else:
             model = self.conditions_treeview.get_model()
 
@@ -362,7 +363,8 @@ class TriggersPluginConfigDialog(GajimPluginConfigDialog):
         # event
         value = self.config[self.active_num]['event']
         if value:
-            self.event_combobox.set_active(self.events_list.keys().index(value))
+            self.event_combobox.set_active(list(self.events_list.keys()).index(
+                value))
         else:
             self.event_combobox.set_active(-1)
         # recipient_type
@@ -447,8 +449,14 @@ class TriggersPluginConfigDialog(GajimPluginConfigDialog):
         (model, iter_) = self.conditions_treeview.get_selection().get_selected()
         if not iter_:
             return
-        event = self.event_combobox.get_active_text()
-        recipient_type = self.recipient_type_combobox.get_active_text()
+        ind = self.event_combobox.get_active()
+        event = ''
+        if ind > -1:
+            event = self.event_combobox.get_model()[ind][0]
+        ind = self.recipient_type_combobox.get_active()
+        recipient_type = ''
+        if ind > -1:
+            recipient_type = self.recipient_type_combobox.get_model()[ind][0]
         recipient = ''
         if recipient_type != 'everybody':
             recipient = self.recipient_list_entry.get_text()
@@ -551,7 +559,7 @@ class TriggersPluginConfigDialog(GajimPluginConfigDialog):
         if active == -1:
             return
         else:
-            event = self.events_list.keys()[active]
+            event = list(self.events_list.keys())[active]
         self.config[self.active_num]['event'] = event
         for w in ('use_systray_cb', 'disable_systray_cb', 'use_roster_cb',
         'disable_roster_cb'):
@@ -576,7 +584,7 @@ class TriggersPluginConfigDialog(GajimPluginConfigDialog):
     def on_recipient_list_entry_changed(self, widget):
         if self.active_num < 0:
             return
-        recipients = widget.get_text().decode('utf-8')
+        recipients = widget.get_text()
         #TODO: do some check
         self.config[self.active_num]['recipients'] = recipients
         self.set_treeview_string()
@@ -707,19 +715,18 @@ class TriggersPluginConfigDialog(GajimPluginConfigDialog):
             self.config[self.active_num]['sound_file'] = path_to_snd_file
             self.sound_entry.set_text(path_to_snd_file)
 
-        path_to_snd_file = self.sound_entry.get_text().decode('utf-8')
+        path_to_snd_file = self.sound_entry.get_text()
         path_to_snd_file = os.path.join(os.getcwd(), path_to_snd_file)
         dialog = SoundChooserDialog(path_to_snd_file, on_ok)
 
     def on_play_button_clicked(self, widget):
-        helpers.play_sound_file(self.sound_entry.get_text().decode('utf-8'))
+        helpers.play_sound_file(self.sound_entry.get_text())
 
     def on_disable_sound_cb_toggled(self, widget):
         self.on_disable_it_toggled(widget, self.use_sound_cb, 'sound')
 
     def on_sound_entry_changed(self, widget):
-        self.config[self.active_num]['sound_file'] = widget.get_text().\
-            decode('utf-8')
+        self.config[self.active_num]['sound_file'] = widget.get_text()
 
     def on_use_popup_cb_toggled(self, widget):
         self.on_use_it_toggled(widget, self.disable_popup_cb, 'popup')
@@ -741,8 +748,7 @@ class TriggersPluginConfigDialog(GajimPluginConfigDialog):
             self.command_entry.set_sensitive(False)
 
     def on_command_entry_changed(self, widget):
-        self.config[self.active_num]['command'] = widget.get_text().\
-            decode('utf-8')
+        self.config[self.active_num]['command'] = widget.get_text()
 
     def on_use_systray_cb_toggled(self, widget):
         self.on_use_it_toggled(widget, self.disable_systray_cb, 'systray')
@@ -770,7 +776,7 @@ class TriggersPluginConfigDialog(GajimPluginConfigDialog):
 
     def on_hide(self, widget):
         # save config
-        for n in self.plugin.config:
+        for n in list(self.plugin.config.keys()):
             del self.plugin.config[n]
         for n in self.config:
             self.plugin.config[str(n)] = self.config[n]
